JiebaDictAssets class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

loadPaths() Future<Map<JiebaDictType, String>>
获取内置结巴分词文件在 AssetBundle 中的路径。由于涉及访问 AssetBundle 的资源,该方法需要在主隔离(Main Isolate)中调用。