JiebaDictType enum

结巴分词所需的字典文件,每个字典文件视为一个类型,详见 simple_tokenizer.cc

Inheritance
Available extensions

Values

jiebaDict → const JiebaDictType
const JiebaDictType("jieba.dict.utf8")
hmmModel → const JiebaDictType
const JiebaDictType("hmm_model.utf8")
userDict → const JiebaDictType
const JiebaDictType("user.dict.utf8")
idf → const JiebaDictType
const JiebaDictType("idf.utf8")
stopWords → const JiebaDictType
const JiebaDictType("stop_words.utf8")

Properties

filename String
文件名
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

byFilename Map<String, JiebaDictType>
filenameJiebaDictType 的映射
final

Constants

values → const List<JiebaDictType>
A constant List of the values in this enum, in order of their declaration.