SimpleBridgeCallbacks class abstract

宿主侧对 wasm_snapshot_preview1 导入模块的部分实现(与 DartBridgeCallbacks 相似),Simple 扩展需要依赖这些实现才能在 Web 上正常运行。

若需要自定义实现,重写这些方法并标记为 JSExport,再通过加载器挂载到 wasi_snapshot_preview1 上,具体可参考 DefaultSimpleBridgeCallbacksDefaultSimpleWasmModuleLoader

Implementers

Constructors

SimpleBridgeCallbacks()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clock_time_get(int clockId, Object? precision, int timePtr) int
environ_get(int environPtr, int environBufPtr) int
environ_sizes_get(int environCountPtr, int environBufSizePtr) int
fd_close(int fd) int
fd_fdstat_get(int fd, int fdstatPtr) int
fd_fdstat_set_flags(int fd, int flags) int
fd_prestat_dir_name(int fd, int pathPtr, int pathLen) int
fd_prestat_get(int fd, int prestatPtr) int
fd_read(int fd, int iovs, int iovsLen, int nreadPtr) int
fd_seek(int fd, Object? offset, int whence, int newOffsetPtr) int
fd_write(int fd, int iovs, int iovsLen, int nwrittenPtr) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
path_open(int fd, int dirflags, int pathPtr, int pathLen, int oflags, Object? rightsBase, Object? rightsInheriting, int fdflags, int openedFdPtr) int
proc_exit(int code) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited